@@ -605,17 +605,19 @@ reversed."
 		    (setq cont nil))
 		   (t
 		    (viper-execute-ex-command)
-		    (save-window-excursion
-		      (setq viper-ex-work-buf
-			    (get-buffer-create viper-ex-work-buf-name))
-		      (set-buffer viper-ex-work-buf)
-		      (skip-chars-forward " \t")
-		      (cond ((looking-at "|")
-			     (forward-char 1))
-			    ((looking-at "\n")
-			     (setq cont nil))
-			    (t (error "`%s': %s" ex-token viper-SpuriousText)))
-		      ))
+		    (save-excursion
+		      (save-window-excursion
+			(setq viper-ex-work-buf
+			      (get-buffer-create viper-ex-work-buf-name))
+			(set-buffer viper-ex-work-buf)
+			(skip-chars-forward " \t")
+			(cond ((looking-at "|")
+			       (forward-char 1))
+			      ((looking-at "\n")
+			       (setq cont nil))
+			      (t (error
+				  "`%s': %s" ex-token viper-SpuriousText)))
+			)))
 		   ))
 	    ((eq ex-token-type 'non-command)
 	     (error "`%s': %s" ex-token viper-BadExCommand))
@@ -1403,7 +1405,8 @@ reversed."
       (setq ex-addresses (cons (point) nil)))
   (push-mark (point) t)
   (goto-char (car ex-addresses))
-  (beginning-of-line))
+  (beginning-of-line)
+  )
 
 ;; Ex line commands.  COM is join, shift-right or shift-left
 (defun ex-line (com)
