@@ -8,7 +8,7 @@
 
 ;; Copyright (C) 1994 -- 1999 Free Software Foundation, Inc.
 
-(defconst viper-version "3.061 (Polyglot) of February 16, 1999"
+(defconst viper-version "3.08 of October 31, 1999"
   "The current version of Viper")
 
 ;; This file is part of GNU Emacs.
@@ -392,6 +392,7 @@ widget."
     bat-mode
     asm-mode
     prolog-mode
+    flora-mode
 
     text-mode indented-text-mode
     tex-mode latex-mode bibtex-mode
@@ -516,9 +517,11 @@ If Viper is enabled, turn it off.  Otherwise, turn it on."
 	  (setq viper-mode t)
 	  (load-library "viper"))
 
-	(if viper-first-time ; Important check.  Prevents mix-up of startup and 
-	    (progn	     ; expert-level msgs when viper-mode recurses
+	(if viper-first-time ; Important check.  Prevents mix-up of startup 
+	    (progn	     ; and expert-level msgs when viper-mode recurses
 	      (setq viper-first-time nil)
+	      (setq viper-vi-state-cursor-color
+		    (viper-get-cursor-color))
 	      (if (not viper-inhibit-startup-message)
 		  (save-window-excursion
 		    (setq viper-inhibit-startup-message t)
@@ -1199,6 +1202,7 @@ These two lines must come in the order given.
       (viper-harness-minor-mode "view-less")
       (viper-harness-minor-mode "view")
       (viper-harness-minor-mode "reftex")
+      (viper-harness-minor-mode "flyspell")
       ))
 
 
